Démonstration OWASP A07: Identification et Authentification

# OWASP Top 10 2021

## A07:2021 - Identification et Authentification

# Portail de Connexion

## Connexion

Vous êtes banni après 5 tentatives échouées.
Pour réinitialiser, utilisez les extraits de code disponibles dans les explications ci-dessous.

## Bienvenue dans votre tableau de bord

Bonjour, !

## Outil de Brute Force

Entrez une liste de couples login/mot de passe au format `login:password`, un par ligne :